package com.kaixed.kchat.data

import com.kaixed.kchat.data.local.box.ObjectBox.getBox
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.data.local.entity.Contact_
import com.kaixed.kchat.data.local.entity.Messages
import com.kaixed.kchat.data.local.entity.Messages_
import io.objectbox.Box
import io.objectbox.query.QueryBuilder

/**
 * @Author: kaixed
 * @Date: 2024/11/24 13:34
 */
object LocalDatabase {
    private val contactBox by lazy { getBox(Contact::class.java) }

    fun getContactByUsername(contactId: String): Contact? {
        return contactBox.query(Contact_.username.equal(contactId)).build().findFirst()
    }

    private val messagesBox: Box<Messages> by lazy { getBox(Messages::class.java) }

    fun getMessagesWithContact(contactId: String, offset: Long, limit: Long): List<Messages> {
        val query = messagesBox
            .query(Messages_.takerId.equal(contactId))
            .order(Messages_.timestamp, QueryBuilder.DESCENDING)
            .build()
        return query.find(offset, limit)
    }

    fun getMoreMessages(contactId: String, msgLocalId: Long, limit: Long): List<Messages> {
        val query = messagesBox
            .query(Messages_.takerId.equal(contactId))
            .lessOrEqual(Messages_.msgLocalId, msgLocalId)
            .order(Messages_.timestamp, QueryBuilder.DESCENDING)
            .build()
        val offset = 0
        return query.find(offset.toLong(), limit)
    }
}