package com.kaixed.kchat.data.repository

import com.kaixed.kchat.data.local.box.ObjectBox.getBoxStore
import com.kaixed.kchat.data.local.entity.UserInfo
import com.kaixed.kchat.data.local.entity.UserInfo_
import com.kaixed.kchat.data.model.request.RegisterRequest
import com.kaixed.kchat.data.model.response.register.Register
import com.kaixed.kchat.network.ApiCall.apiCall
import com.kaixed.kchat.network.RetrofitClient
import com.kaixed.kchat.utils.Constants.MMKV_USER_SESSION
import com.tencent.mmkv.MMKV
import io.objectbox.Box

/**
 * @Author: kaixed
 * @Date: 2024/11/23 14:15
 */
class UserAuthRepository {

    private val userApiService = RetrofitClient.userApiService

    private val userInfoBox: Box<UserInfo> by lazy { getBoxStore().boxFor(UserInfo::class.java) }

    private val mmkv by lazy { MMKV.mmkvWithID(MMKV_USER_SESSION) }

    // 用户注册
    suspend fun register(registerRequest: RegisterRequest): Result<Register?> {
        return apiCall(
            apiCall = { userApiService.register(registerRequest) },
            errorMessage = "注册成功，但未返回用户数据"
        ).onSuccess { register ->
            register?.let {
                insertUserInfo(register, registerRequest.telephone)
            }
        }
    }

    // 登录方法
    suspend fun loginByUsername(username: String, password: String): Result<UserInfo?> {
        return apiCall(
            apiCall = { userApiService.loginByUsername(username, password) },
            errorMessage = "登录成功，但未返回用户数据"
        ).onSuccess { userInfo ->
            userInfo?.let {
                updateDb(userInfo)
            }
        }
    }


    suspend fun loginByTelephone(telephone: String, password: String): Result<UserInfo?> {
        return apiCall(
            apiCall = { userApiService.loginByTelephone(telephone, password) },
            errorMessage = "登录成功，但未返回用户数据"
        ).onSuccess { userInfo ->
            userInfo?.let {
                updateDb(userInfo)
            }
        }
    }

    private fun insertUserInfo(
        register: Register,
        telephone: String
    ) {
        val userInfo = UserInfo(
            username = register.username,
            nickname = register.nickname,
            avatarUrl = "",
            signature = "",
            telephone = telephone
        )
        userInfoBox.put(userInfo)
    }

    private fun updateDb(userInfo: UserInfo) {
        mmkv.apply {
            encode("username", userInfo.username)
            encode("nickname", userInfo.nickname)
            encode("avatarUrl", userInfo.avatarUrl)
        }
        MMKV.defaultMMKV().encode("userLoginStatus", true)
        val user = userInfoBox
            .query(UserInfo_.username.equal(userInfo.username))
            .build()
            .findFirst()
        if (user == null) {
            userInfoBox.put(userInfo)
        }
    }
}
