package com.kaixed.kchat.ui.activity

import android.annotation.SuppressLint
import android.app.TaskStackBuilder
import android.content.Intent
import android.os.Bundle
import androidx.activity.enableEdgeToEdge
import androidx.activity.viewModels
import com.kaixed.kchat.databinding.ActivityApproveContactRequestBinding
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.utils.ConstantsUtil.getUsername
import com.kaixed.kchat.viewmodel.ContactViewModel

class ApproveContactRequestActivity : BaseActivity<ActivityApproveContactRequestBinding>() {

    private val contactViewModel: ContactViewModel by viewModels()

    private lateinit var nickname: String

    private lateinit var message: String

    private lateinit var contactId: String

    override fun inflateBinding(): ActivityApproveContactRequestBinding {
        return ActivityApproveContactRequestBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()


        setContent()

        setOnClickListener()
    }

    override fun initData() {
        nickname = intent.getStringExtra("nickname").toString()
        message = intent.getStringExtra("message").toString()
        contactId = intent.getStringExtra("contactId").toString()
    }

    @SuppressLint("SetTextI18n")
    private fun setContent() {
        binding.etRemark.setText(nickname)
        binding.tvMessage.text = "‘$message’"
    }

    private fun setOnClickListener() {
        binding.tvFinish.setOnClickListener {
            acceptContactRequest(contactId!!, nickname!!)
        }
    }

    private fun acceptContactRequest(contactId: String, nickname: String) {
        contactViewModel.acceptContactRequestResult
            .observe(this) { result ->

                result.onSuccess {
                    val stackBuilder: TaskStackBuilder = TaskStackBuilder.create(this)
                    stackBuilder.addNextIntentWithParentStack(
                        Intent(
                            this, MainActivity::class.java
                        )
                    )
                    stackBuilder.addNextIntent(
                        Intent(
                            this, ChatActivity::class.java
                        ).apply {
                            putExtra("contactId", contactId)
                            putExtra("contactNickname", nickname)
                        }
                    )
                    stackBuilder.startActivities()
                }

                result.onFailure { toast(it.message.toString()) }
            }

        val remark = binding.etRemark.text.toString()

        contactViewModel.acceptContactRequest(getUsername(), contactId, remark)
    }
}

