package com.kaixed.kchat.ui.activity

import android.annotation.SuppressLint
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.activity.enableEdgeToEdge
import com.kaixed.kchat.data.local.box.ObjectBox.getBoxStore
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.data.local.entity.Contact_
import com.kaixed.kchat.databinding.ActivityContactsDetailBinding
import com.kaixed.kchat.ui.base.BaseActivity
import io.objectbox.Box

class ContactsDetailActivity : BaseActivity<ActivityContactsDetailBinding>() {

    private val contactBox: Box<Contact> by lazy { getBoxStore().boxFor(Contact::class.java) }

    private var contactId: String? = null

    private var contactNickname: String? = null

    companion object {
        private const val TAG = "ContactsDetailActivity"
    }

    override fun inflateBinding(): ActivityContactsDetailBinding {
        return ActivityContactsDetailBinding.inflate(layoutInflater)
    }

    @SuppressLint("SetTextI18n")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        setOnListener()

        updateContent()
    }

    override fun initData() {
        contactId = intent.getStringExtra("contactId")
    }

    @SuppressLint("SetTextI18n")
    private fun updateContent() {
        val contact: Contact by lazy {
            getContactInfo(contactId!!)
        }
        binding.tvContactId.text = "kid: $contactId"
        binding.tvContactSignature.text = contact.signature
        if (contact.remark?.isNotEmpty() == true) {
            binding.tvRemark.text = contact.remark
            contactNickname = contact.remark
            binding.tvContactName.text = "昵称：${contact.nickname}"
        } else {
            contactNickname = contact.nickname
            binding.tvRemark.text = contact.nickname
            binding.tvContactName.visibility = View.GONE
        }
    }

    override fun onResume() {
        super.onResume()
        updateContent()
    }

    private fun setOnListener() {
        binding.rlSendMessage.setOnClickListener {
            startActivity(Intent(this, ChatActivity::class.java).apply {
                putExtra("contactId", contactId)
                putExtra("contactNickname", contactId)
            })
        }

        binding.ciSetRemarkAndLabel.setOnClickListener {
            startActivity(Intent(this, SetRemarkAndLabelActivity::class.java).apply {
                putExtra("contactId", contactId)
                putExtra("contactNickname", contactNickname)
            })
        }

        binding.ctb.setOnSettingClickListener {
            startActivity(Intent(this, DataSettingActivity::class.java).apply {
                putExtra("contactId", contactId)
            })
        }

        binding.ciPermission.setOnClickListener {
            startActivity(
                Intent(this, ContactPermissionActivity::class.java)
            )
        }
    }

    private fun getContactInfo(contactId: String): Contact {
        return contactBox
            .query(Contact_.username.equal(contactId))
            .build()
            .findFirst()!!
    }
}
