package com.kaixed.kchat.ui.activity

import android.os.Bundle
import android.os.Handler
import android.os.Looper
import androidx.activity.enableEdgeToEdge
import androidx.activity.viewModels
import androidx.core.widget.addTextChangedListener
import com.kaixed.kchat.data.local.box.ObjectBox.getBoxStore
import com.kaixed.kchat.data.local.entity.UserInfo
import com.kaixed.kchat.databinding.ActivityRenameBinding
import com.kaixed.kchat.data.model.request.UserRequest
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.ui.widget.LoadingDialogFragment
import com.kaixed.kchat.utils.ConstantsUtil.getNickName
import com.kaixed.kchat.utils.ConstantsUtil.getUsername
import com.kaixed.kchat.viewmodel.UserViewModel
import io.objectbox.Box

class RenameActivity : BaseActivity<ActivityRenameBinding>() {

    private val userInfoBox: Box<UserInfo> by lazy { getBoxStore().boxFor(UserInfo::class.java) }

    private val userViewModel: UserViewModel by viewModels()

    private var oldNickname: String = ""

    private var updateSucceed = false


    override fun inflateBinding(): ActivityRenameBinding {
        return ActivityRenameBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        val nickname = oldNickname
        var enable = false

        binding.etNickname.setText(nickname)

        binding.etNickname.addTextChangedListener(
            afterTextChanged = { et ->
                val nowNickname = getNickName()
                enable = et.toString() != nowNickname
                binding.ctb.setBtnEnable(et.toString() != nowNickname)
            }
        )

        binding.ctb.setOnBtnClickListener {
            if (enable) {
                updateNicknamesByCondition(binding.etNickname.text.toString(), getUsername())
            }
        }
    }

    override fun initData() {
        oldNickname = getNickName()
    }

    private fun updateNicknamesByCondition(newNickname: String, username: String) {
        binding.ctb.setBtnEnable(false)
        val dialog: LoadingDialogFragment = LoadingDialogFragment.newInstance("正在保存")
        dialog.showLoading(supportFragmentManager)
        userViewModel.changeNicknameResult.observe(this) { result ->

            result.onSuccess {
                binding.etNickname.setText(newNickname)
                updateSucceed = true
            }

            result.onFailure {
                updateSucceed = false
                binding.etNickname.setText(oldNickname)
            }

            binding.etNickname.setSelection(binding.etNickname.text.length)
        }
        val userRequest = UserRequest(
            username = username,
            nickname = newNickname
        )
        userViewModel.changeNickname(userRequest)
        Handler(Looper.getMainLooper()).postDelayed({
            dialog.dismissLoading()
            toast(if (updateSucceed) "更新成功" else "更新失败")
        }, 800)
    }

    override fun onResume() {
        super.onResume()
        val nickname = getNickName()
        binding.etNickname.setText(nickname)
    }
}