package com.kaixed.kchat.ui.activity

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.view.View
import android.view.inputmethod.InputMethodManager
import androidx.activity.enableEdgeToEdge
import androidx.core.content.ContextCompat
import androidx.core.widget.addTextChangedListener
import androidx.lifecycle.lifecycleScope
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.kaixed.kchat.R
import com.kaixed.kchat.data.local.box.ObjectBox.getBoxStore
import com.kaixed.kchat.data.LocalDatabase
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.databinding.ActivitySetRemarkAndLabelBinding
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.ui.widget.LoadingDialogFragment
import com.kaixed.kchat.utils.ConstantsUtil.getUsername
import com.kaixed.kchat.viewmodel.ContactViewModel
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch

class SetRemarkAndLabelActivity : BaseActivity<ActivitySetRemarkAndLabelBinding>() {

    private val contactBox by lazy {
        getBoxStore().boxFor(Contact::class.java)
    }

    private var contactId: String? = null

    private var hasFocus = false

    private var remark = ""

    private val contact: Contact? by lazy {
        LocalDatabase.getContactByUsername(contactId!!)
    }

    private val contactViewModel by lazy { ContactViewModel() }

    override fun inflateBinding(): ActivitySetRemarkAndLabelBinding {
        return ActivitySetRemarkAndLabelBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        updateContent()

        setOnListener()
    }

    override fun initData() {
        contactId = intent?.getStringExtra("contactId") ?: ""
        remark = contact?.remark ?: contact?.nickname ?: ""
    }

    override fun onResume() {
        super.onResume()
        updateContent()
    }

    private fun updateContent() {
        binding.etRemark.setText(remark)
        updateByFocus()
        if (hasFocus) {
            binding.etRemark.setSelection(remark.length)
        }
    }

    private fun setOnListener() {
        binding.etRemark.setOnFocusChangeListener { _, hasFocus ->
            this.hasFocus = hasFocus
            updateByFocus()
        }

        binding.ivClean.setOnClickListener {
            remark = ""
            binding.etRemark.setText(remark)
            binding.ivClean.visibility = View.INVISIBLE
        }

        binding.ctb.setOnBtnClickListener {
            updateRemark()
        }

        binding.etRemark.addTextChangedListener(afterTextChanged = { text ->
            remark = text.toString()
        })

        binding.cvAddLabel.setOnClickListener { toast() }

        binding.cvAddTelephone.setOnClickListener { toast() }
    }

    private fun hideKeyboard(view: View) {
        view.clearFocus()
        val imm = this.getSystemService(Context.INPUT_METHOD_SERVICE) as? InputMethodManager
        imm?.hideSoftInputFromWindow(view.windowToken, 0)
    }

    private fun updateRemark() {
        hideKeyboard(binding.etRemark)

        val dialog = LoadingDialogFragment.newInstance("正在保存")
        dialog.showLoading(supportFragmentManager)

        contactViewModel.setRemarkResult.observe(this) { result ->
            result.onSuccess {
                val deleteIntent = Intent("com.kaixed.kchat.broadcast.UPDATE_CONTACT_LIST")
                deleteIntent.putExtra("update", true)
                LocalBroadcastManager.getInstance(this).sendBroadcast(deleteIntent)
                lifecycleScope.launch {
                    delay(1000)
                    dialog.dismissLoading()
                    finish()
                }
            }
            result.onFailure {
                toast(it.message.toString())
                dialog.dismissLoading()
            }

        }
        contactViewModel.setRemark(getUsername(), contactId!!, remark)
    }

    private fun updateByFocus() {
        if (hasFocus) {
            binding.etRemark.setTextColor(ContextCompat.getColor(this, R.color.black))
            binding.ivClean.visibility = View.VISIBLE
            binding.ctb.setBtnEnable(true)
        } else {
            binding.etRemark.setTextColor(Color.parseColor("#ACACAC"))
            binding.ivClean.visibility = View.GONE
        }
    }
}
