package com.kaixed.kchat.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.bumptech.glide.Glide
import com.drake.spannable.replaceSpan
import com.drake.spannable.span.CenterImageSpan
import com.kaixed.kchat.R
import com.kaixed.kchat.data.local.box.ObjectBox
import com.kaixed.kchat.data.local.entity.Messages
import com.kaixed.kchat.databinding.ChatRecycleItemCustomNormalBinding
import com.kaixed.kchat.databinding.ChatRecycleItemImageNormalBinding
import com.kaixed.kchat.databinding.ChatRecycleItemTipBinding
import com.kaixed.kchat.utils.ConstantsUtil.getUsername
import com.kaixed.kchat.utils.ViewUtil.changeTimerVisibility
import com.kaixed.kchat.utils.ViewUtil.changeView
import io.objectbox.Box
import java.util.LinkedList


class ChatAdapter(
    private val context: Context, private val messages: LinkedList<Messages>
) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    companion object {
        const val CUSTOM = 0

        // 提示消息
        const val TIP = 2

        // 图片消息
        const val IMAGE = 4

        // 语音消息
        const val VOICE = 6

        // 位置消息
        const val LOCATION = 8

        // 表情消息
        const val EMOJI = 10

        // 红包消息
        const val RED_PACKET = 12

        private const val TAG = "ChatAdapter"
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return when (viewType) {
            CUSTOM -> {
                CustomViewHolder(
                    ChatRecycleItemCustomNormalBinding.inflate(
                        LayoutInflater.from(parent.context), parent, false
                    )
                )
            }

            IMAGE -> {
                ImageViewHolder(
                    ChatRecycleItemImageNormalBinding.inflate(
                        LayoutInflater.from(parent.context), parent, false
                    )
                )
            }

            else -> {
                TipViewHolder(
                    ChatRecycleItemTipBinding.inflate(
                        LayoutInflater.from(parent.context), parent, false
                    )
                )
            }
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val singleMessage = messages[position]

        when (holder) {
            is CustomViewHolder -> {
                holder.bindData(singleMessage)
                changeTimerVisibility(position, messages, holder.binding.tvTimer, singleMessage)
            }

            is ImageViewHolder -> {
                holder.bindData(singleMessage)
                changeTimerVisibility(position, messages, holder.binding.tvTimer, singleMessage)
            }

            is TipViewHolder -> {
                holder.bindData(singleMessage)
            }

        }
    }

    class TipViewHolder(val binding: ChatRecycleItemTipBinding) :
        RecyclerView.ViewHolder(binding.root) {
        fun bindData(message: Messages) {
            if (message.show) {
                binding.tvTip.text = binding.root.context.getString(
                    R.string.withdraw_message_format, message.senderId
                )
            }
        }
    }


    class CustomViewHolder(val binding: ChatRecycleItemCustomNormalBinding) :
        RecyclerView.ViewHolder(binding.root) {
        fun bindData(message: Messages) {
            val sender = message.senderId == getUsername()
            binding.tvMessageContent.text = message.content.replaceSpan("[委屈]") {
                CenterImageSpan(binding.root.context, R.drawable.emoji).setDrawableSize(55)
            }

            changeView(
                parentView = binding.root,
                sender = sender,
                avatarId = binding.ifvAvatar.id,
                contentId = binding.tvMessageContent.id
            )
        }
    }


    class ImageViewHolder(val binding: ChatRecycleItemImageNormalBinding) :
        RecyclerView.ViewHolder(binding.root) {
        fun bindData(message: Messages) {
            Glide.with(binding.root.context).load(message.content)
                .placeholder(R.drawable.bac_contacts_detail).into(binding.image)
            val sender = message.senderId == getUsername()
            changeView(
                parentView = binding.root,
                sender = sender,
                avatarId = binding.ifvAvatar.id,
                contentId = binding.image.id
            )
        }
    }

    override fun getItemViewType(position: Int): Int {
        return messages[position].type.toInt()

    }

    private fun updateDb(message: Messages) {
        val messagesBox: Box<Messages> = ObjectBox.getBoxStore().boxFor(Messages::class.java)
        messagesBox.put(message)
    }

    override fun getItemCount(): Int = messages.size
}
