package com.kaixed.kchat.ui.adapter

import android.content.Context
import android.content.Intent
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.RecyclerView.ViewHolder
import com.bumptech.glide.Glide
import com.kaixed.kchat.data.model.friend.FriendRequestItem
import com.kaixed.kchat.databinding.FriendRecycleItemAddRequestBinding
import com.kaixed.kchat.ui.activity.ApproveContactRequestActivity
import com.kaixed.kchat.ui.activity.ApproveDetailActivity

/**
 * @Author: kaixed
 * @Date: 2024/10/18 15:08
 */
class ContactRequestListAdapter(
    private val items: MutableList<FriendRequestItem>,
    val context: Context
) :
    RecyclerView.Adapter<ContactRequestListAdapter.MyViewHolder>() {

    class MyViewHolder(val binding: FriendRecycleItemAddRequestBinding) : ViewHolder(binding.root)

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): MyViewHolder {
        val binding = FriendRecycleItemAddRequestBinding.inflate(
            LayoutInflater.from(parent.context),
            parent,
            false
        )
        return MyViewHolder(binding)
    }

    override fun getItemCount(): Int = items.size

    override fun onBindViewHolder(holder: MyViewHolder, position: Int) {
        holder.binding.root.setOnClickListener {
            val intent = Intent(context, ApproveDetailActivity::class.java)
            intent.putExtra("request", items[position])
            context.startActivity(intent)
        }

        holder.binding.tvAdd.setOnClickListener {
            context.startActivity(
                Intent(context, ApproveContactRequestActivity::class.java).apply {
                    putExtra("request", items[position])
                    putExtra("nickname", items[position].nickname)
                    putExtra("contactId", items[position].username)
                    putExtra("message", items[position].message)
                }
            )
        }

        holder.binding.top.visibility = if (position == 0) View.GONE else View.VISIBLE
        holder.binding.bottom.visibility =
            if (position == items.size - 1) View.GONE else View.VISIBLE

        Glide.with(context).load(items[position].avatarUrl).into(holder.binding.ifvAvatar)
        holder.binding.tvMessage.text = items[position].message
        holder.binding.tvNickname.text = items[position].nickname
    }
}
