package com.kaixed.kchat.ui.adapter

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import com.bumptech.glide.Glide
import com.bumptech.glide.request.RequestOptions
import com.drake.spannable.replaceSpan
import com.drake.spannable.span.CenterImageSpan
import com.kaixed.kchat.R
import com.kaixed.kchat.data.local.entity.Conversation
import com.kaixed.kchat.databinding.ChatMainItemBinding
import com.kaixed.kchat.ui.activity.ChatActivity
import com.kaixed.kchat.ui.i.OnItemListener
import com.kaixed.kchat.utils.TextUtil

/**
 * @Author: kaixed
 * @Date: 2024/10/27 18:22
 */
class ConversationAdapter(
    private val context: Context
) : ListAdapter<Conversation, ConversationAdapter.MyViewHolder>(ConversationDiffCallback()) {

    private var onItemListener: OnItemListener? = null

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): MyViewHolder {
        val binding = ChatMainItemBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return MyViewHolder(binding)
    }

    override fun onBindViewHolder(
        holder: MyViewHolder,
        @SuppressLint("RecyclerView") position: Int
    ) {
        val options = RequestOptions()
            .placeholder(R.drawable.ic_default_avatar)
            .error(R.drawable.ic_default_avatar)

        val chatList = getItem(position)

        holder.binding.main.setBackgroundColor(if (chatList.isPinned) Color.parseColor("#EDEDED") else Color.WHITE)

        if (chatList.avatarUrl.isNotEmpty()) {
            Glide.with(context).load(chatList.avatarUrl).apply(options)
                .into(holder.binding.ifvAvatar)
        }

        if (chatList.unreadCount != 0) {
            holder.binding.tvUnreadCount.text = chatList.unreadCount.toString()
            holder.binding.rlUnreadCount.visibility = View.VISIBLE
        } else {
            holder.binding.rlUnreadCount.visibility = View.INVISIBLE
        }

        holder.bind(chatList, context)
        holder.itemView.setOnClickListener {
            onItemListener!!.onItemClick(chatList.talkerId)

            context.startActivity(Intent(context, ChatActivity::class.java).apply {
                putExtra("contactId", chatList.talkerId)
                putExtra("contactNickname", chatList.nickname)
            })
        }

        holder.itemView.setOnLongClickListener {
            onItemListener!!.onItemLongClick(chatList.talkerId, chatList.nickname)
            true
        }
    }

    inner class MyViewHolder(val binding: ChatMainItemBinding) :
        RecyclerView.ViewHolder(binding.root) {
        fun bind(chatList: Conversation, context: Context) {
            binding.tvContent.text = chatList.lastContent.replaceSpan("[委屈]") {
                CenterImageSpan(context, R.drawable.emoji).setDrawableSize(55)
            }
            binding.tvNickname.text = chatList.talkerId
            binding.tvTimestamp.text = TextUtil.getTimestampString(chatList.timestamp)
        }
    }

    fun setItemListener(i: OnItemListener?) {
        this.onItemListener = i
    }

    class ConversationDiffCallback : DiffUtil.ItemCallback<Conversation>() {
        override fun areItemsTheSame(oldItem: Conversation, newItem: Conversation): Boolean {
            return oldItem.talkerId == newItem.talkerId
        }

        override fun areContentsTheSame(oldItem: Conversation, newItem: Conversation): Boolean {
            return oldItem == newItem
        }
    }
}
