package com.kaixed.kchat.ui.adapter

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.RecyclerView.ViewHolder
import com.bumptech.glide.Glide
import com.bumptech.glide.request.RequestOptions
import com.kaixed.kchat.R
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.databinding.FriendRecycleFooterItemBinding
import com.kaixed.kchat.databinding.FriendRecycleItemBinding
import com.kaixed.kchat.ui.activity.ContactRequestListActivity
import com.kaixed.kchat.ui.activity.ContactsDetailActivity

/**
 * @Author: kaixed
 * @Date: 2024/10/14 14:47
 */
class FriendListAdapter(var items: MutableList<Contact>, private val context: Context) :
    RecyclerView.Adapter<ViewHolder>() {

    class ItemViewHolder(val binding: FriendRecycleItemBinding) : ViewHolder(binding.root)

    class FooterViewHolder(val binding: FriendRecycleFooterItemBinding) : ViewHolder(binding.root)

    fun updateData(newData: List<Contact>) {
        items.clear()
        items.addAll(newData)
        notifyDataSetChanged()
    }

    companion object {
        const val TYPE_ITEM: Int = 0
        const val TYPE_FOOTER: Int = 1
        private const val TAG = "FriendListAdapter"
    }

    private val defaultItems = listOf(
        R.drawable.ic_contact_new_friend,
        R.drawable.ic_contact_group,
        R.drawable.ic_contact_label,
        R.drawable.ic_contact_public_account,
        R.drawable.ic_contact_service_account
    )

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        return when (viewType) {
            TYPE_FOOTER -> {
                val binding = FriendRecycleFooterItemBinding.inflate(
                    LayoutInflater.from(parent.context), parent, false
                )
                FooterViewHolder(binding)
            }

            else -> {
                val binding = FriendRecycleItemBinding.inflate(
                    LayoutInflater.from(parent.context), parent, false
                )
                ItemViewHolder(binding)
            }
        }
    }

    @SuppressLint("SetTextI18n")
    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        when (holder) {
            is FooterViewHolder -> {
                holder.binding.tvTip.text = "${itemCount - defaultItems.size - 1} 个朋友"
            }

            is ItemViewHolder -> {
                if (position == 0) {
                    holder.binding.root.setOnClickListener {
                        context.startActivity(
                            Intent(
                                context,
                                ContactRequestListActivity::class.java
                            )
                        )
                    }
                }
                val item = items[position]
                holder.binding.tvItemName.text = item.remark ?: item.nickname

                if (item.showHeader == true) {
                    if (item.remarkquanpin != null) {
                        if (item.remarkquanpin?.substring(0, 1)?.uppercase()
                                ?.matches(Regex("[a-zA-Z]+")) == false
                        ) {
                            holder.binding.tvLetter.text =
                                "#"
                        } else {
                            holder.binding.tvLetter.text =
                                item.remarkquanpin?.substring(0, 1)?.uppercase()
                        }
                    } else {
                        holder.binding.tvLetter.text = item.quanpin?.substring(0, 1)?.uppercase()
                    }
                    holder.binding.tvLetter.visibility = ViewGroup.VISIBLE
                } else {
                    holder.binding.tvLetter.visibility = ViewGroup.GONE
                }

                if (position <= defaultItems.size - 1) {
                    if (position == 0) {
                        holder.binding.rlUnreadCount.visibility =
                            if (item.avatarUrl != null) View.VISIBLE else View.GONE

                        if (item.avatarUrl != null) {
                            val options = RequestOptions()
                                .placeholder(R.drawable.ic_default_avatar)
                                .error(R.drawable.ic_default_avatar)
                            Glide.with(context).load(item.avatarUrl).apply(options)
                                .into(holder.binding.ifvAvatar)
                        } else {
                            holder.binding.ifvAvatar.setImageResource(defaultItems[position])
                            holder.binding.ifvAvatar.setBackgroundColor(context.getColor(R.color.gray))
                        }
                    } else {
                        holder.binding.ifvAvatar.setImageResource(defaultItems[position])
                        holder.binding.ifvAvatar.setBackgroundColor(context.getColor(R.color.gray))
                    }
                    if (position == defaultItems.size - 1) {
                        holder.binding.viewBottom.visibility =
                            if (items.size == 5) View.VISIBLE else View.INVISIBLE
                    }

                } else {
                    val options = RequestOptions()
                        .placeholder(R.drawable.ic_default_avatar)
                        .error(R.drawable.ic_default_avatar)
                    Glide.with(context).load(item.avatarUrl).apply(options)
                        .into(holder.binding.ifvAvatar)
                    holder.binding.root.setOnClickListener {
                        val intent = Intent(context, ContactsDetailActivity::class.java)
                        intent.putExtra("contactId", item.username)
                        context.startActivity(intent)
                    }
                }
            }
        }
    }

    override fun getItemCount(): Int = items.size + 1

    override fun getItemViewType(position: Int): Int {
        return if (position + 1 == getItemCount()) {
            TYPE_FOOTER
        } else {
            TYPE_ITEM
        }
    }
}
