package com.kaixed.kchat.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.BaseAdapter
import com.kaixed.kchat.data.model.FunctionItem
import com.kaixed.kchat.databinding.FunctionGridItemBinding
import com.kaixed.kchat.ui.i.IOnItemClickListener

/**
 * @Author: kaixed
 * @Date: 2024/10/27 18:29
 */
class FunctionPanelAdapter(
    private val items: List<FunctionItem>,
    private val context: Context
) : BaseAdapter() {

    // 监听器接口，外部可以传递点击事件的处理方法
    private var listener: IOnItemClickListener? = null

    // 设置点击事件监听器
    fun setOnItemClickListener(listener: IOnItemClickListener) {
        this.listener = listener
    }

    override fun getCount(): Int = items.size

    override fun getItem(position: Int): Any = items[position]

    override fun getItemId(position: Int): Long = position.toLong()

    // 用于设置 GridItem 的视图
    override fun getView(position: Int, convertView: View?, parent: ViewGroup?): View {
        val binding: FunctionGridItemBinding
        val view: View

        if (convertView == null) {
            // convertView 为空时，需要创建新的视图
            binding = FunctionGridItemBinding.inflate(LayoutInflater.from(context), parent, false)
            view = binding.root
            view.tag = binding // 将 binding 存入 tag，以便复用
        } else {
            // convertView 不为空时，直接复用已有的 View
            view = convertView
            binding = view.tag as FunctionGridItemBinding
        }

        // 设置项的名称和图标
        val functionItem = items[position]
        binding.tvItemName.text = functionItem.itemName
        binding.ivItem.setImageResource(functionItem.iconResId)

        // 设置点击事件
        binding.main.setOnClickListener {
            listener?.onFunctionItemClick(position)
        }

        return view
    }
}
