package com.kaixed.kchat.ui.adapter

import android.annotation.SuppressLint
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.kaixed.kchat.databinding.SearchRecycleItemContactsBinding
import com.kaixed.kchat.databinding.SearchRecycleItemDetailsBinding
import com.kaixed.kchat.data.model.search.SearchItem

/**
 * @Author: kaixed
 * @Date: 2024/10/27 18:34
 */
class SearchResultAdapter(
    private val displayedItems: List<Any>
) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return when (viewType) {
            0 -> {
                val binding = SearchRecycleItemContactsBinding.inflate(
                    LayoutInflater.from(parent.context),
                    parent,
                    false
                )
                GroupViewHolder(binding)
            }

            else -> {
                val binding = SearchRecycleItemDetailsBinding.inflate(
                    LayoutInflater.from(parent.context),
                    parent,
                    false
                )
                DetailsViewHolder(binding)
            }
        }
    }

    @SuppressLint("SetTextI18n")
    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        when (holder.itemViewType) {
            0 -> {
                val groupViewHolder = holder as GroupViewHolder
                groupViewHolder.binding.tvName.text = displayedItems[position].toString()
            }

            1 -> {
                val detailsViewHolder = holder as DetailsViewHolder
                val item = displayedItems[position] as? SearchItem
                item?.let {
                    detailsViewHolder.binding.tvName.text = it.name
                    if (it.hasMore) {
                        detailsViewHolder.binding.tvHasMore.text = "更多${it.type}"
                        detailsViewHolder.binding.rlHasMore.visibility = View.VISIBLE
                        detailsViewHolder.binding.view.visibility = View.INVISIBLE
                    } else {
                        detailsViewHolder.binding.rlHasMore.visibility = View.GONE
                        detailsViewHolder.binding.view.visibility = View.VISIBLE
                    }
                }
            }
        }
    }

    override fun getItemViewType(position: Int): Int {
        return when (displayedItems[position]) {
            is String -> 0
            is SearchItem -> 1
            else -> -1 // 处理意外情况
        }
    }

    override fun getItemCount(): Int {
        return displayedItems.size
    }

    // ViewHolder for Group Items
    class GroupViewHolder(val binding: SearchRecycleItemContactsBinding) :
        RecyclerView.ViewHolder(binding.root)

    // ViewHolder for Detail Items
    class DetailsViewHolder(val binding: SearchRecycleItemDetailsBinding) :
        RecyclerView.ViewHolder(binding.root)
}
