package com.kaixed.kchat.ui.base

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.core.view.updatePadding
import androidx.fragment.app.Fragment
import androidx.viewbinding.ViewBinding
import com.kaixed.kchat.utils.ConstantsUtil.getStatusBarHeight

/**
 * @Author: kaixed
 * @Date: 2024/10/31 11:04
 */
abstract class BaseFragment<VB : ViewBinding> : Fragment() {

    private var _binding: VB? = null
    protected val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        _binding = inflateBinding(inflater, container)
        return binding.root
    }

    abstract fun inflateBinding(inflater: LayoutInflater, container: ViewGroup?): VB

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        setupStatusBarPadding(binding.root)
    }

    private fun setupStatusBarPadding(rootView: View) {
        val statusBarHeight = getStatusBarHeight()
        rootView.updatePadding(top = statusBarHeight)
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}
