package com.kaixed.kchat.ui.fragment

import android.animation.Animator
import android.animation.AnimatorListenerAdapter
import android.animation.ObjectAnimator
import android.annotation.SuppressLint
import android.content.ComponentName
import android.content.Context
import android.content.Intent
import android.content.ServiceConnection
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Build
import android.os.Bundle
import android.os.IBinder
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.appcompat.app.AppCompatActivity.BIND_AUTO_CREATE
import androidx.recyclerview.widget.LinearLayoutManager
import com.kaixed.kchat.R
import com.kaixed.kchat.data.local.box.ObjectBox.getBoxStore
import com.kaixed.kchat.data.local.entity.Conversation
import com.kaixed.kchat.data.local.entity.Conversation_
import com.kaixed.kchat.data.model.HomeItem
import com.kaixed.kchat.databinding.FragmentHomeBinding
import com.kaixed.kchat.service.WebSocketService
import com.kaixed.kchat.service.WebSocketService.LocalBinder
import com.kaixed.kchat.ui.activity.AddFriendsActivity
import com.kaixed.kchat.ui.activity.SearchActivity
import com.kaixed.kchat.ui.activity.TestActivity
import com.kaixed.kchat.ui.adapter.ConversationAdapter
import com.kaixed.kchat.ui.adapter.MyGridAdapter
import com.kaixed.kchat.ui.base.BaseFragment
import com.kaixed.kchat.ui.i.OnDialogFragmentClickListener
import com.kaixed.kchat.ui.i.OnItemListener
import com.kaixed.kchat.ui.widget.HomeDialogFragment
import io.objectbox.Box

class HomeFragment : BaseFragment<FragmentHomeBinding>(), OnItemListener,
    OnDialogFragmentClickListener {

    private var chatLists: MutableList<Conversation> = mutableListOf()

    private val conversationAdapter: ConversationAdapter by lazy {
        ConversationAdapter(requireContext())
    }

    private val conversationBox: Box<Conversation> by lazy { getBoxStore().boxFor(Conversation::class.java) }

    private var talkerId: String? = null

    private val items: List<HomeItem> by lazy { getHomeItems() }

    private var webSocketService: WebSocketService? = null

    private var flipped = false

    private var bound = false

    private lateinit var context: Context

    private var connection: ServiceConnection = object : ServiceConnection {
        override fun onServiceConnected(className: ComponentName, service: IBinder) {
            val binder = service as LocalBinder
            webSocketService = binder.getService()
            bound = true
            observeLiveData()
        }

        override fun onServiceDisconnected(arg0: ComponentName) {
            bound = false
        }
    }

    override fun inflateBinding(
        inflater: LayoutInflater,
        container: ViewGroup?
    ): FragmentHomeBinding {
        return FragmentHomeBinding.inflate(inflater, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        context = requireContext()
        initView()
        startService()
        setOnClick()
    }

    private fun setOnClick() {
        binding.ifvAvatar.setOnClickListener {
            startActivity(Intent(context, TestActivity::class.java))
        }
        binding.ivMessage.setOnClickListener {
        }
        binding.ivSearch.setOnClickListener {
            val intent = Intent(context, SearchActivity::class.java)
            startActivity(intent)
        }
    }

    private fun flipImage(v: View) {
        val flipAnimation = if (flipped) {
            ObjectAnimator.ofFloat(v, "rotationX", 180f, 0f)
        } else {
            ObjectAnimator.ofFloat(v, "rotationX", 0f, 180f)
        }
        flipAnimation.setDuration(0)
        flipAnimation.start()
        flipped = !flipped
    }

    @SuppressLint("NotifyDataSetChanged")
    fun notifyData() {
        conversationAdapter.notifyDataSetChanged()
    }

    private fun startService() {
        val intent = Intent(context, WebSocketService::class.java)
        context.startService(intent)
    }

    private fun observeLiveData() {
        if (webSocketService == null) {
            return
        }
        webSocketService!!.conversations.observe(viewLifecycleOwner) {
            it?.let {
                chatLists = it.toMutableList()
                conversationAdapter.submitList(chatLists)
                notifyData()
            }
        }
    }

    private fun initView() {
        setupGridView()
        setupRecycleView()
        setupMoreOptionsToggle()
    }

    private fun setupMoreOptionsToggle() {
        binding.ivMore.setOnClickListener { v ->
            flipImage(v)
            val gridViewHeight = binding.gridView.height
            val startAt: Int
            val endAt: Int
            if (flipped) {
                binding.gridView.visibility = View.VISIBLE
                startAt = 0
                endAt = gridViewHeight
            } else {
                startAt = gridViewHeight
                endAt = 0
            }
            createAnimator(startAt, endAt).start()
        }
    }

    private fun createAnimator(start: Int, end: Int): ObjectAnimator {
        val animator = ObjectAnimator.ofInt(binding.linearlayout, "top", start, end)
        val duration: Long = 500
        animator.setDuration(duration)

        animator.addListener(object : AnimatorListenerAdapter() {
            override fun onAnimationStart(animation: Animator) {
                super.onAnimationStart(animation)
                binding.ivMore.isEnabled = false
            }

            override fun onAnimationEnd(animation: Animator) {
                super.onAnimationEnd(animation)
                if (!flipped) {
                    binding.gridView.visibility = View.INVISIBLE
                }
                binding.ivMore.isEnabled = true
            }
        })
        return animator
    }

    private fun setupRecycleView() {
//        conversationBox.all?.let {
//            chatLists = conversationBox.query(Conversation_.show.equal(true)).build().find()
//        }
        binding.recycleChatList.layoutManager =
            LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        binding.recycleChatList.adapter = conversationAdapter
        binding.recycleChatList.setHasFixedSize(true)
        conversationAdapter.setItemListener(this)
    }

    private fun resetContent() {
        flipImage(binding.ivMore)
        flipped = false
    }

    enum class HomeItems(val title: String, val iconResId: Int, val isEnabled: Boolean) {
        CHANGE_BACKGROUND("更换背景", R.drawable.ic_switch, true),
        CREATE_GROUP("创建群聊", R.drawable.ic_troop, false),
        ADD_FRIENDS("新朋友", R.drawable.ic_friend, true),
        CHANGE_MODE("夜间模式", R.drawable.ic_night, true),
        FRIEND_CIRCLE("朋友圈", R.drawable.ic_qzone, false),
        SCAN("扫一扫", R.drawable.ic_scan, false),
        FRIENDS("通讯录", R.drawable.ic_clock_in, true),
        CLOSE_APP("关闭应用", R.drawable.ic_exit, false);

        companion object {
            fun getAllItems() = entries
        }
    }

    private fun getHomeItems(): List<HomeItem> {
        return HomeItems.getAllItems().map { homeItem ->
            HomeItem(homeItem.title, homeItem.isEnabled, homeItem.iconResId)
        }
    }


    private fun setupGridView() {
        val myGridAdapter = MyGridAdapter(context, items)
        binding.gridView.adapter = myGridAdapter

        binding.gridView.selector = ColorDrawable(Color.TRANSPARENT)

        binding.gridView.setOnItemClickListener { _, _, position, _ ->
            val homeItem = items[position]
            when (HomeItems.valueOf(homeItem.name)) {
                HomeItems.ADD_FRIENDS -> {
                    val intent = Intent(context, AddFriendsActivity::class.java)
                    startActivity(intent)
                }

                HomeItems.CLOSE_APP -> {
                    requireActivity().finishAffinity()
                }

                else -> Toast.makeText(requireContext(), "暂未实现", Toast.LENGTH_SHORT).show()
            }
        }

    }

    override fun onResume() {
        super.onResume()
        if (flipped) {
            resetContent()
        }
//        updateChatLists()
    }

    @RequiresApi(Build.VERSION_CODES.TIRAMISU)
    override fun onStart() {
        super.onStart()
        val intent = Intent(context, WebSocketService::class.java)
        requireActivity().bindService(intent, connection, BIND_AUTO_CREATE)
    }

    override fun onStop() {
        super.onStop()
        if (bound) {
            context.unbindService(connection)
            bound = false
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        val intent = Intent(
            context,
            WebSocketService::class.java
        )
        context.stopService(intent)
    }

    override fun onItemClick(talkerId: String) {
        this.talkerId = talkerId
//        chatLists.find { it.talkerId == talkerId }?.let {
//            it.unreadCount = 0
//            conversationBox.put(it)
//        }
        for (i in chatLists.indices) {
            if (chatLists[i].talkerId == talkerId) {
                chatLists[i].unreadCount = 0
            }
        }
        notifyData()
//
        val conversation =
            conversationBox.query(Conversation_.talkerId.equal(talkerId)).build().findFirst()

        conversation?.let {
            it.unreadCount = 0
            conversationBox.put(it)
        }
    }

    private var longClickTalkerId = ""

    private var con: Conversation? = null


    override fun onItemLongClick(talkId: String, nickname: String) {
        longClickTalkerId = talkId
        con = getConversation(talkId)
        val dialogFragment = HomeDialogFragment.newInstance(
            contactNickname = nickname,
            isPinned = con!!.isPinned,
            isHasUnreadMsg = con!!.unreadCount != 0
        )
        dialogFragment.show(childFragmentManager, "HomeDialogFragment")
    }

    private fun getConversation(): Conversation =
        chatLists.find { it.talkerId == longClickTalkerId }!!

    private fun getConversation(talkId: String): Conversation =
        chatLists.find { it.talkerId == talkId }!!


    override fun onClickSetUnread() {
        if (con == null) {
            return
        }
        webSocketService?.updateConversationList(con!!.apply {
            this.unreadCount = if (unreadCount != 0) 0 else 1
        })
    }

    override fun onClickHideConversation() {
        webSocketService?.updateConversationList(getConversation().apply {
            this.isShow = false
        })
    }

    override fun onClickSticky() {
        webSocketService?.updateConversationList(getConversation().apply {
            this.isPinned = !isPinned
        })
    }

    override fun onClickDeleteConversation() {
        webSocketService?.deleteConversationList(getConversation())
    }
}
