package com.kaixed.kchat.ui.widget

import android.app.Activity
import android.content.Context
import android.graphics.Color
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.core.content.ContextCompat
import com.kaixed.kchat.R
import com.kaixed.kchat.databinding.ViewTitleBarBinding

/**
 * @Author: kaixed
 * @Date: 2024/10/10 22:13
 */
class CustomTitleBar @JvmOverloads constructor(
    context: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0,
) : ConstraintLayout(context, attrs, defStyleAttr) {

    private var binding: ViewTitleBarBinding =
        ViewTitleBarBinding.inflate(LayoutInflater.from(context), this, true)

    private var isBtnEnabled: Boolean = false

    init {
        attrs?.let {
            val typedArray = context.obtainStyledAttributes(it, R.styleable.CustomTitleBar, 0, 0)
            val titleName = typedArray.getString(R.styleable.CustomTitleBar_titleName) ?: ""
            val titleIcon = typedArray.getResourceId(R.styleable.CustomTitleBar_titleIcon, -1)
            val btnName = typedArray.getString(R.styleable.CustomTitleBar_btnName) ?: ""


            if (titleIcon != -1) {
                binding.ivSetting.visibility = View.VISIBLE
                binding.ivSetting.setImageResource(titleIcon)
            } else {
                binding.ivSetting.visibility = View.GONE
            }

            if (titleName.isNotEmpty()) {
                binding.tvTitleName.visibility = View.VISIBLE
                binding.tvTitleName.text = titleName
            } else {
                binding.tvTitleName.visibility = View.GONE
            }

            if (btnName.isNotEmpty()) {
                binding.tvSave.visibility = View.VISIBLE
                binding.tvSave.text = btnName
            } else {
                binding.tvSave.visibility = View.INVISIBLE
            }

            typedArray.recycle()
        }

        binding.ivBack.setOnClickListener {
            (context as? Activity)?.finish()
        }
    }

    fun setOnSettingClickListener(listener: OnClickListener?) {
        binding.ivSetting.setOnClickListener(listener)
    }

    fun setOnTitleClickListener(listener: OnClickListener?) {
        binding.tvTitleName.setOnClickListener(listener)
    }

    fun setBtnEnable(enable: Boolean) {
        isBtnEnabled = enable
        val colorEnable = ContextCompat.getColor(context, R.color.white)
        val color = Color.parseColor("#BFBFBF")
        binding.tvSave.setTextColor(if (enable) colorEnable else color)
        binding.tvSave.setBackgroundResource(if (enable) R.drawable.bac_ctb_save_enable else R.drawable.bac_ctb_save)
    }

    fun setOnBtnClickListener(listener: OnClickListener?) {
        binding.tvSave.setOnClickListener {
            if (isBtnEnabled) {
                listener?.onClick(it)
            }
        }
    }

    fun setTitleName(titleName: String) {
        binding.tvTitleName.text = titleName
    }
}
