package com.kaixed.kchat.ui.widget

import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.view.Gravity
import android.view.Window
import android.view.WindowManager
import androidx.fragment.app.DialogFragment
import com.kaixed.kchat.databinding.DialogHomeBinding
import com.kaixed.kchat.ui.i.OnDialogFragmentClickListener
import kotlin.properties.Delegates

class HomeDialogFragment : DialogFragment() {

    private lateinit var contactNickname: String
    private var isPinned by Delegates.notNull<Boolean>()
    private var isHasUnreadMsg by Delegates.notNull<Boolean>()
    private var listener: OnDialogFragmentClickListener? = null

    companion object {
        fun newInstance(
            contactNickname: String,
            isPinned: Boolean = false,
            isHasUnreadMsg: Boolean = false
        ): HomeDialogFragment {
            val fragment = HomeDialogFragment()
            val args = Bundle()
            args.putString("contactNickname", contactNickname)
            args.putBoolean("isPinned", isPinned)
            args.putBoolean("isHasUnreadMsg", isHasUnreadMsg)
            fragment.arguments = args
            return fragment
        }
    }

    override fun onAttach(context: Context) {
        super.onAttach(context)
        val parentFragment = parentFragment
        listener = if (parentFragment is OnDialogFragmentClickListener) {
            parentFragment
        } else if (context is OnDialogFragmentClickListener) {
            context
        } else {
            throw IllegalStateException(
                "Either parent fragment or activity must implement OnDialogFragmentClickListener"
            )
        }
    }

    override fun onDetach() {
        super.onDetach()
        listener = null
    }

    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        contactNickname = arguments?.getString("contactNickname") ?: ""
        isPinned = arguments?.getBoolean("isPinned") ?: false
        isHasUnreadMsg = arguments?.getBoolean("isHasUnreadMsg") ?: false

        val binding = DialogHomeBinding.inflate(layoutInflater)
        val dialog = Dialog(requireContext())
        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
//        dialog.setCancelable(false)
        dialog.setContentView(binding.root)
        dialog.window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))

        val layoutParams = WindowManager.LayoutParams().apply {
            copyFrom(dialog.window?.attributes)
            width = (requireContext().resources.displayMetrics.widthPixels * 0.8).toInt()
            gravity = Gravity.CENTER
        }
        dialog.window?.attributes = layoutParams

        setContent(binding)

        setOnClickListener(binding)
        return dialog
    }

    private fun setContent(binding: DialogHomeBinding) {
        binding.tvTitle.text = contactNickname
        binding.tvSticky.text = if (isPinned) "取消置顶" else "置顶"
        binding.tvSetUnread.text = if (isHasUnreadMsg) "标记已读" else "标记未读"
    }

    private fun setOnClickListener(binding: DialogHomeBinding) {
        binding.tvSetUnread.setOnClickListener {
            listener?.onClickSetUnread()
            dismissDialog()
        }

        binding.tvSticky.setOnClickListener {
            listener?.onClickSticky()
            dismissDialog()
        }
        binding.tvHideConversation.setOnClickListener {
            listener?.onClickHideConversation()
            dismissDialog()
        }
        binding.tvDeleteConversation.setOnClickListener {
            listener?.onClickDeleteConversation()
            dismissDialog()
        }
    }

    private fun dismissDialog() {
        if (isAdded && !isStateSaved) {
            dismissAllowingStateLoss()
        }
    }
}
