package com.kaixed.kchat.ui.widget

import android.app.Dialog
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.view.Window
import androidx.fragment.app.DialogFragment
import androidx.fragment.app.FragmentManager
import com.kaixed.kchat.databinding.DialogLoadingBinding
import com.kaixed.kchat.utils.DensityUtil.dpToPx

class LoadingDialogFragment : DialogFragment() {

    private var loadingText: String = ""

    companion object {
        fun newInstance(text: String): LoadingDialogFragment {
            val fragment = LoadingDialogFragment()
            val bundle = Bundle()
            bundle.putString("loading_text", text)
            fragment.arguments = bundle
            return fragment
        }
    }

    // 创建对话框
    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        val binding = DialogLoadingBinding.inflate(layoutInflater)
        val dialog = Dialog(requireContext())
        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
        dialog.setCancelable(false)
        dialog.setContentView(binding.root)
        dialog.window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))

        dialog.setCancelable(false)  // 禁止点击外部区域关闭对话框
        dialog.setCanceledOnTouchOutside(false)  // 禁止点击外部区域消失

        // 获取传入的 loading_text 参数
        loadingText = arguments?.getString("loading_text", "") ?: "加载中..."
        binding.tvLoading.text = loadingText

        // 设置对话框的大小
        val params = binding.root.layoutParams
        params.height = dpToPx(150)
        params.width = dpToPx(150)
        binding.root.layoutParams = params

        return dialog
    }

    // 显示对话框
    fun showLoading(fragmentManager: FragmentManager) {
        if (!this.isAdded) {  // 避免重复添加
            this.show(fragmentManager, "LoadingDialogFragment")
        }
    }

    // 关闭对话框
    fun dismissLoading() {
        if (isAdded && !isStateSaved) {
            dismissAllowingStateLoss()
        }
    }
}
