package com.kaixed.kchat.utils

import com.kaixed.kchat.utils.Constants.AVATAR_URL
import com.kaixed.kchat.utils.Constants.CURRENT_CONTACT_ID
import com.kaixed.kchat.utils.Constants.FIRST_LAUNCH_APP
import com.kaixed.kchat.utils.Constants.KEYBOARD_DEFAULT_HEIGHT
import com.kaixed.kchat.utils.Constants.KEYBOARD_HEIGHT
import com.kaixed.kchat.utils.Constants.MMKV_COMMON_DATA
import com.kaixed.kchat.utils.Constants.MMKV_USER_SESSION
import com.kaixed.kchat.utils.Constants.NICKNAME_KEY
import com.kaixed.kchat.utils.Constants.STATUS_BAR_DEFAULT_HEIGHT
import com.kaixed.kchat.utils.Constants.STATUS_BAR_HEIGHT
import com.kaixed.kchat.utils.Constants.USERNAME_KEY
import com.tencent.mmkv.MMKV

/**
 * @Author: kaixed
 * @Date: 2024/10/24 22:04
 */
object ConstantsUtil {

    private val commonDataMMKV by lazy { MMKV.mmkvWithID(MMKV_COMMON_DATA) }
    private val userSessionMMKV by lazy { MMKV.mmkvWithID(MMKV_USER_SESSION) }
    private val defaultMMKV by lazy { MMKV.defaultMMKV() }

    fun getKeyboardHeight(): Int =
        commonDataMMKV.getInt(KEYBOARD_HEIGHT, KEYBOARD_DEFAULT_HEIGHT)

    fun getUsername(): String =
        userSessionMMKV.getString(USERNAME_KEY, "") ?: ""

    fun getAvatarUrl(): String =
        userSessionMMKV.getString(AVATAR_URL, "") ?: ""

    fun getStatusBarHeight(): Int =
        commonDataMMKV.getInt(STATUS_BAR_HEIGHT, STATUS_BAR_DEFAULT_HEIGHT)

    fun getNickName(): String =
        userSessionMMKV.getString(NICKNAME_KEY, "") ?: ""

    fun getCurrentContactId(): String =
        userSessionMMKV.getString(CURRENT_CONTACT_ID, "") ?: ""

    fun isFirstLaunchApp(): Boolean {
        val isFirstLaunch = defaultMMKV.getBoolean(FIRST_LAUNCH_APP, true)

        if (isFirstLaunch) {
            defaultMMKV.putBoolean(FIRST_LAUNCH_APP, false)
        }
        return isFirstLaunch
    }

}
