package com.kaixed.kchat.utils

import android.content.Context
import android.graphics.drawable.ColorDrawable
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.PopupWindow
import androidx.core.view.updateMargins
import com.kaixed.kchat.databinding.PopwindowsBinding
import com.kaixed.kchat.utils.DensityUtil.dpToPx

/**
 * @Author: kaixed
 * @Date: 2024/11/25 15:44
 */
object PopWindowUtil {

    fun showPopupWindow(context: Context, parentView: View, isMine: Boolean) {
        val binding: PopwindowsBinding = PopwindowsBinding.inflate(LayoutInflater.from(context))
        val popupWindow: PopupWindow = PopupWindow(
            binding.root, ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT
        ).apply {
            isFocusable = true
            isOutsideTouchable = true
            setBackgroundDrawable(ColorDrawable())
        }

        // 获取屏幕的总宽度
        val screenWidth = context.resources.displayMetrics.widthPixels
        val screenHeight = context.resources.displayMetrics.heightPixels

        val location = IntArray(2)
        parentView.getLocationOnScreen(location)
        binding.root.measure(View.MeasureSpec.UNSPECIFIED, View.MeasureSpec.UNSPECIFIED)

        // popupWindow的长度
        val popupWidth = binding.root.measuredWidth
        val popupHeight = binding.root.measuredHeight

        val parentWidth = parentView.width
        val parentHeight = parentView.height

        val parentX = location[0]

        // 父布局中心点横坐标
        val distanceToLeftEdge = parentX + parentView.width / 2
        // 中心点距离右侧距离
        val distanceToRightEdge = screenWidth - distanceToLeftEdge


        binding.ivArrowDown.measure(View.MeasureSpec.UNSPECIFIED, View.MeasureSpec.UNSPECIFIED)
        val arrowWidth = binding.ivArrowDown.measuredWidth

        val isYEnoughSpace = (screenHeight - popupHeight) > popupHeight
        val xOffset: Int
        val yOffset = if (isYEnoughSpace) -popupHeight - parentHeight + arrowWidth / 3 else 0
        val marginStart: Int

        var rightEnough = false
        var leftEnough = false

        if (isYEnoughSpace) {
            binding.ivArrowUp.visibility = View.GONE
            binding.ivArrowDown.visibility = View.VISIBLE
        } else {
            binding.ivArrowUp.visibility = View.VISIBLE
            binding.ivArrowDown.visibility = View.GONE
        }


        if (isMine) {
            rightEnough = (popupWidth / 2) < distanceToRightEdge
            xOffset = if (rightEnough)
                (parentWidth - popupWidth) / 2
            else
                parentWidth - popupWidth + dpToPx(45)

            marginStart = popupWidth - (dpToPx(55) + parentWidth / 2)

        } else {
            leftEnough = (popupWidth / 2) < distanceToLeftEdge
            xOffset = if (leftEnough) parentWidth - popupWidth
            else -dpToPx(45)

            marginStart = dpToPx(35) + parentWidth / 2
        }


        binding.ivArrowDown.layoutParams =
            (binding.ivArrowUp.layoutParams as LinearLayout.LayoutParams).apply {
                val enoughSpace = if (isMine) rightEnough else leftEnough
                if (enoughSpace) {
                    gravity = Gravity.CENTER_HORIZONTAL
                } else {
                    updateMargins(left = marginStart)
                }
            }

        popupWindow.showAsDropDown(parentView, xOffset, yOffset)

//        binding.ivWithdraw.setOnClickListener {
//            messages[position].status = "withdraw"
//            updateDb(messages[position])
//            notifyItemChanged(position)
//            popupWindow.dismiss()
//        }
    }
}