package com.kaixed.kchat.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.kaixed.kchat.data.local.entity.UserInfo
import com.kaixed.kchat.data.model.request.RegisterRequest
import com.kaixed.kchat.data.model.request.UserRequest
import com.kaixed.kchat.data.model.response.register.Register
import com.kaixed.kchat.data.model.response.search.User
import com.kaixed.kchat.data.model.search.SearchUser
import com.kaixed.kchat.data.repository.UserAuthRepository
import com.kaixed.kchat.data.repository.UserProfileRepository
import com.kaixed.kchat.data.repository.UserSearchRepository
import kotlinx.coroutines.launch
import okhttp3.MultipartBody

class UserViewModel : ViewModel() {

    private val userAuthRepo = UserAuthRepository()

    private val userProfileRepo = UserProfileRepository()

    private val userSearchRepo = UserSearchRepository()

    private val _loginResult = MutableLiveData<Result<UserInfo?>>()
    val loginResult: LiveData<Result<UserInfo?>> = _loginResult

    fun loginByUsername(username: String, password: String) {
        viewModelScope.launch {
            val result = userAuthRepo.loginByUsername(username, password)
            _loginResult.postValue(result)
        }
    }

    fun loginByTelephone(username: String, password: String) {
        viewModelScope.launch {
            val result = userAuthRepo.loginByTelephone(username, password)
            _loginResult.postValue(result)
        }
    }

    private val _registerResult = MutableLiveData<Result<Register?>>()
    val registerResult: LiveData<Result<Register?>> = _registerResult

    // 注册请求
    fun register(registerRequest: RegisterRequest) {
        viewModelScope.launch {
            val result = userAuthRepo.register(registerRequest)
            _registerResult.postValue(result)
        }
    }

    private val _userListResult = MutableLiveData<Result<List<User>>>()
    val userListResult: LiveData<Result<List<User>>> = _userListResult

    // 获取用户列表
    fun getUserList(username: String) {
        viewModelScope.launch {
            val result = userSearchRepo.getUserList(username)
            _userListResult.postValue(result)
        }
    }

    private val _userInfoResult = MutableLiveData<Result<SearchUser>>()
    val userInfoResult: LiveData<Result<SearchUser>> = _userInfoResult

    // 获取用户信息
    fun getUserInfo(username: String) {
        viewModelScope.launch {
            val result = userProfileRepo.getUserInfo(username)
            _userInfoResult.postValue(result)
        }
    }

    private val _changeNicknameResult = MutableLiveData<Result<Boolean>>()
    val changeNicknameResult: LiveData<Result<Boolean>> = _changeNicknameResult

    // 修改昵称
    fun changeNickname(userRequest: UserRequest) {
        viewModelScope.launch {
            val result = userProfileRepo.changeNickname(userRequest)
            _changeNicknameResult.postValue(result)
        }
    }

    private val _uploadAvatarResult = MutableLiveData<Result<String>>()
    val uploadAvatarResult: LiveData<Result<String>> = _uploadAvatarResult

    // 上传头像
    fun uploadAvatar(file: MultipartBody.Part, username: String) {
        viewModelScope.launch {
            val result = userProfileRepo.uploadAvatar(file, username)
            _uploadAvatarResult.postValue(result)
        }
    }
}
